var searchData=
[
  ['saxdocumentbuilder',['SAXDocumentBuilder',['../servicecom_1_1sun_1_1star_1_1xml_1_1dom_1_1SAXDocumentBuilder.html',1,'com::sun::star::xml::dom']]],
  ['saxdocumenthandler',['SaxDocumentHandler',['../servicecom_1_1sun_1_1star_1_1xml_1_1input_1_1SaxDocumentHandler.html',1,'com::sun::star::xml::input']]],
  ['saxeventkeeper',['SAXEventKeeper',['../servicecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1SAXEventKeeper.html',1,'com::sun::star::xml::crypto::sax']]],
  ['saxexception',['SAXException',['../exceptioncom_1_1sun_1_1star_1_1xml_1_1sax_1_1SAXException.html',1,'com::sun::star::xml::sax']]],
  ['saxinvalidcharacterexception',['SAXInvalidCharacterException',['../exceptioncom_1_1sun_1_1star_1_1xml_1_1sax_1_1SAXInvalidCharacterException.html',1,'com::sun::star::xml::sax']]],
  ['saxparseexception',['SAXParseException',['../exceptioncom_1_1sun_1_1star_1_1xml_1_1sax_1_1SAXParseException.html',1,'com::sun::star::xml::sax']]],
  ['scaledata',['ScaleData',['../structcom_1_1sun_1_1star_1_1chart2_1_1ScaleData.html',1,'com::sun::star::chart2']]],
  ['scaling',['Scaling',['../servicecom_1_1sun_1_1star_1_1chart2_1_1Scaling.html',1,'com::sun::star::chart2']]],
  ['scannercontext',['ScannerContext',['../structcom_1_1sun_1_1star_1_1scanner_1_1ScannerContext.html',1,'com::sun::star::scanner']]],
  ['scannerexception',['ScannerException',['../exceptioncom_1_1sun_1_1star_1_1scanner_1_1ScannerException.html',1,'com::sun::star::scanner']]],
  ['scannermanager',['ScannerManager',['../servicecom_1_1sun_1_1star_1_1scanner_1_1ScannerManager.html',1,'com::sun::star::scanner']]],
  ['scenario',['Scenario',['../servicecom_1_1sun_1_1star_1_1sheet_1_1Scenario.html',1,'com::sun::star::sheet']]],
  ['scenarios',['Scenarios',['../servicecom_1_1sun_1_1star_1_1sheet_1_1Scenarios.html',1,'com::sun::star::sheet']]],
  ['scenariosenumeration',['ScenariosEnumeration',['../servicecom_1_1sun_1_1star_1_1sheet_1_1ScenariosEnumeration.html',1,'com::sun::star::sheet']]],
  ['schema',['Schema',['../servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1Schema.html',1,'com::sun::star::configuration::backend']]],
  ['schemaparser',['SchemaParser',['../servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1xml_1_1SchemaParser.html',1,'com::sun::star::configuration::backend::xml']]],
  ['schemasupplier',['SchemaSupplier',['../servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1SchemaSupplier.html',1,'com::sun::star::configuration::backend']]],
  ['scode',['SCode',['../structcom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1SCode.html',1,'com::sun::star::bridge::oleautomation']]],
  ['script',['Script',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Script.html',1,'com::sun::star::text::textfield']]],
  ['scripterrorraisedexception',['ScriptErrorRaisedException',['../exceptioncom_1_1sun_1_1star_1_1script_1_1provider_1_1ScriptErrorRaisedException.html',1,'com::sun::star::script::provider']]],
  ['scriptevent',['ScriptEvent',['../structcom_1_1sun_1_1star_1_1script_1_1ScriptEvent.html',1,'com::sun::star::script']]],
  ['scripteventdescriptor',['ScriptEventDescriptor',['../structcom_1_1sun_1_1star_1_1script_1_1ScriptEventDescriptor.html',1,'com::sun::star::script']]],
  ['scriptexceptionraisedexception',['ScriptExceptionRaisedException',['../exceptioncom_1_1sun_1_1star_1_1script_1_1provider_1_1ScriptExceptionRaisedException.html',1,'com::sun::star::script::provider']]],
  ['scriptframeworkerrorexception',['ScriptFrameworkErrorException',['../exceptioncom_1_1sun_1_1star_1_1script_1_1provider_1_1ScriptFrameworkErrorException.html',1,'com::sun::star::script::provider']]],
  ['scriptprovider',['ScriptProvider',['../servicecom_1_1sun_1_1star_1_1script_1_1provider_1_1ScriptProvider.html',1,'com::sun::star::script::provider']]],
  ['scriptproviderforbasic',['ScriptProviderForBasic',['../servicecom_1_1sun_1_1star_1_1script_1_1provider_1_1ScriptProviderForBasic.html',1,'com::sun::star::script::provider']]],
  ['scriptproviderforbeanshell',['ScriptProviderForBeanShell',['../servicecom_1_1sun_1_1star_1_1script_1_1provider_1_1ScriptProviderForBeanShell.html',1,'com::sun::star::script::provider']]],
  ['scriptproviderforjava',['ScriptProviderForJava',['../servicecom_1_1sun_1_1star_1_1script_1_1provider_1_1ScriptProviderForJava.html',1,'com::sun::star::script::provider']]],
  ['scriptproviderforjavascript',['ScriptProviderForJavaScript',['../servicecom_1_1sun_1_1star_1_1script_1_1provider_1_1ScriptProviderForJavaScript.html',1,'com::sun::star::script::provider']]],
  ['scripturihelper',['ScriptURIHelper',['../servicecom_1_1sun_1_1star_1_1script_1_1provider_1_1ScriptURIHelper.html',1,'com::sun::star::script::provider']]],
  ['scrollbar',['ScrollBar',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1ScrollBar.html',1,'com::sun::star::form::component']]],
  ['searchcommandargument',['SearchCommandArgument',['../structcom_1_1sun_1_1star_1_1ucb_1_1SearchCommandArgument.html',1,'com::sun::star::ucb']]],
  ['searchcriterium',['SearchCriterium',['../structcom_1_1sun_1_1star_1_1ucb_1_1SearchCriterium.html',1,'com::sun::star::ucb']]],
  ['searchdescriptor',['SearchDescriptor',['../servicecom_1_1sun_1_1star_1_1util_1_1SearchDescriptor.html',1,'com::sun::star::util']]],
  ['searchinfo',['SearchInfo',['../structcom_1_1sun_1_1star_1_1ucb_1_1SearchInfo.html',1,'com::sun::star::ucb']]],
  ['searchoptions',['SearchOptions',['../structcom_1_1sun_1_1star_1_1util_1_1SearchOptions.html',1,'com::sun::star::util']]],
  ['searchoptions2',['SearchOptions2',['../structcom_1_1sun_1_1star_1_1util_1_1SearchOptions2.html',1,'com::sun::star::util']]],
  ['searchresult',['SearchResult',['../structcom_1_1sun_1_1star_1_1util_1_1SearchResult.html',1,'com::sun::star::util']]],
  ['section',['Section',['../servicecom_1_1sun_1_1star_1_1report_1_1Section.html',1,'com::sun::star::report']]],
  ['sectionfilelink',['SectionFileLink',['../structcom_1_1sun_1_1star_1_1text_1_1SectionFileLink.html',1,'com::sun::star::text']]],
  ['securityenvironment',['SecurityEnvironment',['../servicecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1SecurityEnvironment.html',1,'com::sun::star::xml::crypto']]],
  ['securityexception',['SecurityException',['../exceptioncom_1_1sun_1_1star_1_1uno_1_1SecurityException.html',1,'com::sun::star::uno']]],
  ['securityinfrastructureexception',['SecurityInfrastructureException',['../exceptioncom_1_1sun_1_1star_1_1security_1_1SecurityInfrastructureException.html',1,'com::sun::star::security']]],
  ['seinitializer',['SEInitializer',['../servicecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1SEInitializer.html',1,'com::sun::star::xml::crypto']]],
  ['selection',['Selection',['../structcom_1_1sun_1_1star_1_1awt_1_1Selection.html',1,'com::sun::star::awt']]],
  ['sendinfo',['SendInfo',['../structcom_1_1sun_1_1star_1_1ucb_1_1SendInfo.html',1,'com::sun::star::ucb']]],
  ['sendmailmessagefailedexception',['SendMailMessageFailedException',['../exceptioncom_1_1sun_1_1star_1_1mail_1_1SendMailMessageFailedException.html',1,'com::sun::star::mail']]],
  ['sendmediatypes',['SendMediaTypes',['../structcom_1_1sun_1_1star_1_1ucb_1_1SendMediaTypes.html',1,'com::sun::star::ucb']]],
  ['sequenceinputstream',['SequenceInputStream',['../servicecom_1_1sun_1_1star_1_1io_1_1SequenceInputStream.html',1,'com::sun::star::io']]],
  ['sequenceoutputstream',['SequenceOutputStream',['../servicecom_1_1sun_1_1star_1_1io_1_1SequenceOutputStream.html',1,'com::sun::star::io']]],
  ['sequencetimecontainer',['SequenceTimeContainer',['../servicecom_1_1sun_1_1star_1_1animations_1_1SequenceTimeContainer.html',1,'com::sun::star::animations']]],
  ['serialnumberadapter',['SerialNumberAdapter',['../servicecom_1_1sun_1_1star_1_1security_1_1SerialNumberAdapter.html',1,'com::sun::star::security']]],
  ['servicemanager',['ServiceManager',['../servicecom_1_1sun_1_1star_1_1lang_1_1ServiceManager.html',1,'com::sun::star::lang']]],
  ['servicenotfoundexception',['ServiceNotFoundException',['../exceptioncom_1_1sun_1_1star_1_1ucb_1_1ServiceNotFoundException.html',1,'com::sun::star::ucb']]],
  ['servicenotregisteredexception',['ServiceNotRegisteredException',['../exceptioncom_1_1sun_1_1star_1_1lang_1_1ServiceNotRegisteredException.html',1,'com::sun::star::lang']]],
  ['sessionlistener',['SessionListener',['../servicecom_1_1sun_1_1star_1_1frame_1_1SessionListener.html',1,'com::sun::star::frame']]],
  ['sessionmanager',['SessionManager',['../servicecom_1_1sun_1_1star_1_1frame_1_1SessionManager.html',1,'com::sun::star::frame']]],
  ['setaccess',['SetAccess',['../servicecom_1_1sun_1_1star_1_1configuration_1_1SetAccess.html',1,'com::sun::star::configuration']]],
  ['setelement',['SetElement',['../servicecom_1_1sun_1_1star_1_1configuration_1_1SetElement.html',1,'com::sun::star::configuration']]],
  ['setexpression',['SetExpression',['../servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1SetExpression.html',1,'SetExpression'],['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1SetExpression.html',1,'SetExpression']]],
  ['setpropertytolerantfailed',['SetPropertyTolerantFailed',['../structcom_1_1sun_1_1star_1_1beans_1_1SetPropertyTolerantFailed.html',1,'com::sun::star::beans']]],
  ['settings',['Settings',['../servicecom_1_1sun_1_1star_1_1document_1_1Settings.html',1,'Settings'],['../servicecom_1_1sun_1_1star_1_1frame_1_1Settings.html',1,'Settings']]],
  ['setupdate',['SetUpdate',['../servicecom_1_1sun_1_1star_1_1configuration_1_1SetUpdate.html',1,'com::sun::star::configuration']]],
  ['shadowformat',['ShadowFormat',['../structcom_1_1sun_1_1star_1_1table_1_1ShadowFormat.html',1,'com::sun::star::table']]],
  ['shadowproperties',['ShadowProperties',['../servicecom_1_1sun_1_1star_1_1drawing_1_1ShadowProperties.html',1,'com::sun::star::drawing']]],
  ['shape',['Shape',['../servicecom_1_1sun_1_1star_1_1report_1_1Shape.html',1,'Shape'],['../servicecom_1_1sun_1_1star_1_1sheet_1_1Shape.html',1,'Shape'],['../servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html',1,'Shape'],['../servicecom_1_1sun_1_1star_1_1text_1_1Shape.html',1,'Shape'],['../servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html',1,'Shape']]],
  ['shapecollection',['ShapeCollection',['../servicecom_1_1sun_1_1star_1_1drawing_1_1ShapeCollection.html',1,'com::sun::star::drawing']]],
  ['shapes',['Shapes',['../servicecom_1_1sun_1_1star_1_1drawing_1_1Shapes.html',1,'com::sun::star::drawing']]],
  ['sharedlibrary',['SharedLibrary',['../servicecom_1_1sun_1_1star_1_1loader_1_1SharedLibrary.html',1,'com::sun::star::loader']]],
  ['sheetcell',['SheetCell',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCell.html',1,'com::sun::star::sheet']]],
  ['sheetcellcursor',['SheetCellCursor',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellCursor.html',1,'com::sun::star::sheet']]],
  ['sheetcellrange',['SheetCellRange',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellRange.html',1,'com::sun::star::sheet']]],
  ['sheetcellranges',['SheetCellRanges',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellRanges.html',1,'com::sun::star::sheet']]],
  ['sheetcellrangesenumeration',['SheetCellRangesEnumeration',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellRangesEnumeration.html',1,'com::sun::star::sheet']]],
  ['sheetfilterdescriptor',['SheetFilterDescriptor',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetFilterDescriptor.html',1,'com::sun::star::sheet']]],
  ['sheetlink',['SheetLink',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetLink.html',1,'com::sun::star::sheet']]],
  ['sheetlinks',['SheetLinks',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetLinks.html',1,'com::sun::star::sheet']]],
  ['sheetlinksenumeration',['SheetLinksEnumeration',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetLinksEnumeration.html',1,'com::sun::star::sheet']]],
  ['sheetrangesquery',['SheetRangesQuery',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetRangesQuery.html',1,'com::sun::star::sheet']]],
  ['sheetsortdescriptor',['SheetSortDescriptor',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor.html',1,'com::sun::star::sheet']]],
  ['sheetsortdescriptor2',['SheetSortDescriptor2',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html',1,'com::sun::star::sheet']]],
  ['signaturecreator',['SignatureCreator',['../servicecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1SignatureCreator.html',1,'com::sun::star::xml::crypto::sax']]],
  ['signatureexception',['SignatureException',['../exceptioncom_1_1sun_1_1star_1_1security_1_1SignatureException.html',1,'com::sun::star::security']]],
  ['signatureverifier',['SignatureVerifier',['../servicecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1SignatureVerifier.html',1,'com::sun::star::xml::crypto::sax']]],
  ['simplecommandmail',['SimpleCommandMail',['../servicecom_1_1sun_1_1star_1_1system_1_1SimpleCommandMail.html',1,'com::sun::star::system']]],
  ['simplefileaccess',['SimpleFileAccess',['../servicecom_1_1sun_1_1star_1_1ucb_1_1SimpleFileAccess.html',1,'com::sun::star::ucb']]],
  ['simplefontmetric',['SimpleFontMetric',['../structcom_1_1sun_1_1star_1_1awt_1_1SimpleFontMetric.html',1,'com::sun::star::awt']]],
  ['simplelogring',['SimpleLogRing',['../servicecom_1_1sun_1_1star_1_1logging_1_1SimpleLogRing.html',1,'com::sun::star::logging']]],
  ['simpleregistry',['SimpleRegistry',['../servicecom_1_1sun_1_1star_1_1registry_1_1SimpleRegistry.html',1,'com::sun::star::registry']]],
  ['simplesetaccess',['SimpleSetAccess',['../servicecom_1_1sun_1_1star_1_1configuration_1_1SimpleSetAccess.html',1,'com::sun::star::configuration']]],
  ['simplesetupdate',['SimpleSetUpdate',['../servicecom_1_1sun_1_1star_1_1configuration_1_1SimpleSetUpdate.html',1,'com::sun::star::configuration']]],
  ['simplesystemmail',['SimpleSystemMail',['../servicecom_1_1sun_1_1star_1_1system_1_1SimpleSystemMail.html',1,'com::sun::star::system']]],
  ['singlebackend',['SingleBackend',['../servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1SingleBackend.html',1,'com::sun::star::configuration::backend']]],
  ['singlebackendadapter',['SingleBackendAdapter',['../servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1SingleBackendAdapter.html',1,'com::sun::star::configuration::backend']]],
  ['singlelayerstratum',['SingleLayerStratum',['../servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1SingleLayerStratum.html',1,'com::sun::star::configuration::backend']]],
  ['singleproofreadingerror',['SingleProofreadingError',['../structcom_1_1sun_1_1star_1_1linguistic2_1_1SingleProofreadingError.html',1,'com::sun::star::linguistic2']]],
  ['singlereference',['SingleReference',['../structcom_1_1sun_1_1star_1_1sheet_1_1SingleReference.html',1,'com::sun::star::sheet']]],
  ['singleselectqueryanalyzer',['SingleSelectQueryAnalyzer',['../servicecom_1_1sun_1_1star_1_1sdb_1_1SingleSelectQueryAnalyzer.html',1,'com::sun::star::sdb']]],
  ['singleselectquerycomposer',['SingleSelectQueryComposer',['../servicecom_1_1sun_1_1star_1_1sdb_1_1SingleSelectQueryComposer.html',1,'com::sun::star::sdb']]],
  ['size',['Size',['../structcom_1_1sun_1_1star_1_1awt_1_1Size.html',1,'com::sun::star::awt']]],
  ['slidenumbershape',['SlideNumberShape',['../servicecom_1_1sun_1_1star_1_1presentation_1_1SlideNumberShape.html',1,'com::sun::star::presentation']]],
  ['sliderenderer',['SlideRenderer',['../servicecom_1_1sun_1_1star_1_1drawing_1_1SlideRenderer.html',1,'com::sun::star::drawing']]],
  ['slideshow',['SlideShow',['../servicecom_1_1sun_1_1star_1_1presentation_1_1SlideShow.html',1,'com::sun::star::presentation']]],
  ['slidesorter',['SlideSorter',['../servicecom_1_1sun_1_1star_1_1drawing_1_1SlideSorter.html',1,'com::sun::star::drawing']]],
  ['slidesview',['SlidesView',['../servicecom_1_1sun_1_1star_1_1presentation_1_1SlidesView.html',1,'com::sun::star::presentation']]],
  ['smarttagaction',['SmartTagAction',['../servicecom_1_1sun_1_1star_1_1smarttags_1_1SmartTagAction.html',1,'com::sun::star::smarttags']]],
  ['smarttagrecognizer',['SmartTagRecognizer',['../servicecom_1_1sun_1_1star_1_1smarttags_1_1SmartTagRecognizer.html',1,'com::sun::star::smarttags']]],
  ['smoketestcommandenvironment',['SmoketestCommandEnvironment',['../servicecom_1_1sun_1_1star_1_1deployment_1_1test_1_1SmoketestCommandEnvironment.html',1,'com::sun::star::deployment::test']]],
  ['socketexception',['SocketException',['../exceptioncom_1_1sun_1_1star_1_1io_1_1SocketException.html',1,'com::sun::star::io']]],
  ['socketpermission',['SocketPermission',['../structcom_1_1sun_1_1star_1_1connection_1_1SocketPermission.html',1,'com::sun::star::connection']]],
  ['solver',['Solver',['../servicecom_1_1sun_1_1star_1_1sheet_1_1Solver.html',1,'com::sun::star::sheet']]],
  ['solverconstraint',['SolverConstraint',['../structcom_1_1sun_1_1star_1_1sheet_1_1SolverConstraint.html',1,'com::sun::star::sheet']]],
  ['sortable',['Sortable',['../servicecom_1_1sun_1_1star_1_1util_1_1Sortable.html',1,'com::sun::star::util']]],
  ['sortablegriddatamodel',['SortableGridDataModel',['../servicecom_1_1sun_1_1star_1_1awt_1_1grid_1_1SortableGridDataModel.html',1,'com::sun::star::awt::grid']]],
  ['sortdescriptor',['SortDescriptor',['../servicecom_1_1sun_1_1star_1_1util_1_1SortDescriptor.html',1,'com::sun::star::util']]],
  ['sortdescriptor2',['SortDescriptor2',['../servicecom_1_1sun_1_1star_1_1util_1_1SortDescriptor2.html',1,'com::sun::star::util']]],
  ['sorteddynamicresultsetfactory',['SortedDynamicResultSetFactory',['../servicecom_1_1sun_1_1star_1_1ucb_1_1SortedDynamicResultSetFactory.html',1,'com::sun::star::ucb']]],
  ['sortfield',['SortField',['../structcom_1_1sun_1_1star_1_1util_1_1SortField.html',1,'com::sun::star::util']]],
  ['sortinginfo',['SortingInfo',['../structcom_1_1sun_1_1star_1_1ucb_1_1SortingInfo.html',1,'com::sun::star::ucb']]],
  ['spellchecker',['SpellChecker',['../servicecom_1_1sun_1_1star_1_1linguistic2_1_1SpellChecker.html',1,'com::sun::star::linguistic2']]],
  ['spinbutton',['SpinButton',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1SpinButton.html',1,'com::sun::star::form::component']]],
  ['spinevent',['SpinEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1SpinEvent.html',1,'com::sun::star::awt']]],
  ['spinningprogresscontrolmodel',['SpinningProgressControlModel',['../servicecom_1_1sun_1_1star_1_1awt_1_1SpinningProgressControlModel.html',1,'com::sun::star::awt']]],
  ['spreadsheet',['Spreadsheet',['../servicecom_1_1sun_1_1star_1_1sheet_1_1Spreadsheet.html',1,'com::sun::star::sheet']]],
  ['spreadsheetdocument',['SpreadsheetDocument',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetDocument.html',1,'com::sun::star::sheet']]],
  ['spreadsheetdocumentsettings',['SpreadsheetDocumentSettings',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetDocumentSettings.html',1,'com::sun::star::sheet']]],
  ['spreadsheetdrawpage',['SpreadsheetDrawPage',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetDrawPage.html',1,'com::sun::star::sheet']]],
  ['spreadsheets',['Spreadsheets',['../servicecom_1_1sun_1_1star_1_1sheet_1_1Spreadsheets.html',1,'com::sun::star::sheet']]],
  ['spreadsheetsenumeration',['SpreadsheetsEnumeration',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetsEnumeration.html',1,'com::sun::star::sheet']]],
  ['spreadsheetview',['SpreadsheetView',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetView.html',1,'com::sun::star::sheet']]],
  ['spreadsheetviewpane',['SpreadsheetViewPane',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetViewPane.html',1,'com::sun::star::sheet']]],
  ['spreadsheetviewpanesenumeration',['SpreadsheetViewPanesEnumeration',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetViewPanesEnumeration.html',1,'com::sun::star::sheet']]],
  ['spreadsheetviewsettings',['SpreadsheetViewSettings',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetViewSettings.html',1,'com::sun::star::sheet']]],
  ['sqlcontext',['SQLContext',['../exceptioncom_1_1sun_1_1star_1_1sdb_1_1SQLContext.html',1,'com::sun::star::sdb']]],
  ['sqlerrorevent',['SQLErrorEvent',['../structcom_1_1sun_1_1star_1_1sdb_1_1SQLErrorEvent.html',1,'com::sun::star::sdb']]],
  ['sqlexception',['SQLException',['../exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html',1,'com::sun::star::sdbc']]],
  ['sqlquerycomposer',['SQLQueryComposer',['../servicecom_1_1sun_1_1star_1_1sdb_1_1SQLQueryComposer.html',1,'com::sun::star::sdb']]],
  ['sqlwarning',['SQLWarning',['../exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLWarning.html',1,'com::sun::star::sdbc']]],
  ['ssomanagerfactory',['SSOManagerFactory',['../servicecom_1_1sun_1_1star_1_1auth_1_1SSOManagerFactory.html',1,'com::sun::star::auth']]],
  ['ssopasswordcache',['SSOPasswordCache',['../servicecom_1_1sun_1_1star_1_1auth_1_1SSOPasswordCache.html',1,'com::sun::star::auth']]],
  ['stackablediagram',['StackableDiagram',['../servicecom_1_1sun_1_1star_1_1chart_1_1StackableDiagram.html',1,'com::sun::star::chart']]],
  ['standarddiagramcreationparameters',['StandardDiagramCreationParameters',['../servicecom_1_1sun_1_1star_1_1chart2_1_1StandardDiagramCreationParameters.html',1,'com::sun::star::chart2']]],
  ['startmodule',['StartModule',['../servicecom_1_1sun_1_1star_1_1frame_1_1StartModule.html',1,'com::sun::star::frame']]],
  ['statechangeinprogressexception',['StateChangeInProgressException',['../exceptioncom_1_1sun_1_1star_1_1embed_1_1StateChangeInProgressException.html',1,'com::sun::star::embed']]],
  ['statement',['Statement',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1Statement.html',1,'Statement'],['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Statement.html',1,'Statement'],['../structcom_1_1sun_1_1star_1_1rdf_1_1Statement.html',1,'Statement']]],
  ['statusbarcontroller',['StatusbarController',['../servicecom_1_1sun_1_1star_1_1frame_1_1StatusbarController.html',1,'com::sun::star::frame']]],
  ['statusbarcontrollerfactory',['StatusbarControllerFactory',['../servicecom_1_1sun_1_1star_1_1frame_1_1StatusbarControllerFactory.html',1,'com::sun::star::frame']]],
  ['statusindicatorfactory',['StatusIndicatorFactory',['../servicecom_1_1sun_1_1star_1_1task_1_1StatusIndicatorFactory.html',1,'com::sun::star::task']]],
  ['stockdiagram',['StockDiagram',['../servicecom_1_1sun_1_1star_1_1chart_1_1StockDiagram.html',1,'com::sun::star::chart']]],
  ['storage',['Storage',['../servicecom_1_1sun_1_1star_1_1embed_1_1Storage.html',1,'com::sun::star::embed']]],
  ['storagefactory',['StorageFactory',['../servicecom_1_1sun_1_1star_1_1embed_1_1StorageFactory.html',1,'com::sun::star::embed']]],
  ['storagestream',['StorageStream',['../servicecom_1_1sun_1_1star_1_1embed_1_1StorageStream.html',1,'com::sun::star::embed']]],
  ['storagewrappedtargetexception',['StorageWrappedTargetException',['../exceptioncom_1_1sun_1_1star_1_1embed_1_1StorageWrappedTargetException.html',1,'com::sun::star::embed']]],
  ['store',['Store',['../servicecom_1_1sun_1_1star_1_1ucb_1_1Store.html',1,'com::sun::star::ucb']]],
  ['stratumcreationexception',['StratumCreationException',['../exceptioncom_1_1sun_1_1star_1_1configuration_1_1backend_1_1StratumCreationException.html',1,'com::sun::star::configuration::backend']]],
  ['string',['String',['../servicecom_1_1sun_1_1star_1_1xsd_1_1String.html',1,'com::sun::star::xsd']]],
  ['stringcontext',['StringContext',['../structcom_1_1sun_1_1star_1_1rendering_1_1StringContext.html',1,'com::sun::star::rendering']]],
  ['stringpair',['StringPair',['../structcom_1_1sun_1_1star_1_1beans_1_1StringPair.html',1,'com::sun::star::beans']]],
  ['stringrepresentation',['StringRepresentation',['../servicecom_1_1sun_1_1star_1_1inspection_1_1StringRepresentation.html',1,'com::sun::star::inspection']]],
  ['stringresource',['StringResource',['../servicecom_1_1sun_1_1star_1_1resource_1_1StringResource.html',1,'com::sun::star::resource']]],
  ['stringresourcewithlocation',['StringResourceWithLocation',['../servicecom_1_1sun_1_1star_1_1resource_1_1StringResourceWithLocation.html',1,'com::sun::star::resource']]],
  ['stringresourcewithstorage',['StringResourceWithStorage',['../servicecom_1_1sun_1_1star_1_1resource_1_1StringResourceWithStorage.html',1,'com::sun::star::resource']]],
  ['strokeattributes',['StrokeAttributes',['../structcom_1_1sun_1_1star_1_1rendering_1_1StrokeAttributes.html',1,'com::sun::star::rendering']]],
  ['style',['Style',['../servicecom_1_1sun_1_1star_1_1style_1_1Style.html',1,'com::sun::star::style']]],
  ['stylefamilies',['StyleFamilies',['../servicecom_1_1sun_1_1star_1_1style_1_1StyleFamilies.html',1,'com::sun::star::style']]],
  ['stylefamily',['StyleFamily',['../servicecom_1_1sun_1_1star_1_1style_1_1StyleFamily.html',1,'com::sun::star::style']]],
  ['subincrement',['SubIncrement',['../structcom_1_1sun_1_1star_1_1chart2_1_1SubIncrement.html',1,'com::sun::star::chart2']]],
  ['subject',['Subject',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1Subject.html',1,'com::sun::star::text::textfield::docinfo']]],
  ['submissionpropertyhandler',['SubmissionPropertyHandler',['../servicecom_1_1sun_1_1star_1_1form_1_1inspection_1_1SubmissionPropertyHandler.html',1,'com::sun::star::form::inspection']]],
  ['submitbutton',['SubmitButton',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1SubmitButton.html',1,'SubmitButton'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1SubmitButton.html',1,'SubmitButton']]],
  ['subtitleshape',['SubtitleShape',['../servicecom_1_1sun_1_1star_1_1presentation_1_1SubtitleShape.html',1,'com::sun::star::presentation']]],
  ['subtotalcolumn',['SubTotalColumn',['../structcom_1_1sun_1_1star_1_1sheet_1_1SubTotalColumn.html',1,'com::sun::star::sheet']]],
  ['subtotaldescriptor',['SubTotalDescriptor',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalDescriptor.html',1,'com::sun::star::sheet']]],
  ['subtotalfield',['SubTotalField',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalField.html',1,'com::sun::star::sheet']]],
  ['subtotalfieldsenumeration',['SubTotalFieldsEnumeration',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SubTotalFieldsEnumeration.html',1,'com::sun::star::sheet']]],
  ['svgtools',['SvgTools',['../servicecom_1_1sun_1_1star_1_1graphic_1_1SvgTools.html',1,'com::sun::star::graphic']]],
  ['symbol',['Symbol',['../structcom_1_1sun_1_1star_1_1chart2_1_1Symbol.html',1,'com::sun::star::chart2']]],
  ['symboldescriptor',['SymbolDescriptor',['../structcom_1_1sun_1_1star_1_1formula_1_1SymbolDescriptor.html',1,'com::sun::star::formula']]],
  ['syncdbussessionhelper',['SyncDbusSessionHelper',['../serviceorg_1_1freedesktop_1_1PackageKit_1_1SyncDbusSessionHelper.html',1,'org::freedesktop::PackageKit']]],
  ['synchronousframeloader',['SynchronousFrameLoader',['../servicecom_1_1sun_1_1star_1_1frame_1_1SynchronousFrameLoader.html',1,'com::sun::star::frame']]],
  ['systemclipboard',['SystemClipboard',['../servicecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1SystemClipboard.html',1,'com::sun::star::datatransfer::clipboard']]],
  ['systemdependentxwindow',['SystemDependentXWindow',['../structcom_1_1sun_1_1star_1_1awt_1_1SystemDependentXWindow.html',1,'com::sun::star::awt']]],
  ['systemintegration',['SystemIntegration',['../servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1SystemIntegration.html',1,'com::sun::star::configuration::backend']]],
  ['systemshellexecute',['SystemShellExecute',['../servicecom_1_1sun_1_1star_1_1system_1_1SystemShellExecute.html',1,'com::sun::star::system']]],
  ['systemshellexecuteexception',['SystemShellExecuteException',['../exceptioncom_1_1sun_1_1star_1_1system_1_1SystemShellExecuteException.html',1,'com::sun::star::system']]]
];
